@@ -30,6 +30,8 @@ import (
 	"strings"
 	"testing"
 
+	"k8s.io/client-go/kubernetes"
+
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
 	"github.com/tektoncd/pipeline/pkg/apis/pipeline/v1alpha1"
@@ -39,6 +41,7 @@ import (
 	bldr "github.com/tektoncd/triggers/test/builder"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
+	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/fields"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -66,6 +69,55 @@ func loadExamplePREventBytes() ([]byte, error) {
 	return bytes, nil
 }
 
+func impersonateRBAC(t *testing.T, sa, namespace string, kubeClient kubernetes.Interface) {
+	impersonateName := fmt.Sprintf("impersonate-%s-defaultSA", namespace)
+	role := &rbacv1.Role{
+		ObjectMeta: metav1.ObjectMeta{Name: impersonateName, Namespace: namespace},
+		Rules: []rbacv1.PolicyRule{
+			{
+				Verbs:           []string{"impersonate"},
+				APIGroups:       []string{""},
+				Resources:       []string{"serviceaccounts"},
+				ResourceNames:   nil,
+				NonResourceURLs: nil,
+			},
+		},
+	}
+	_, err := kubeClient.RbacV1().Roles(namespace).Get(impersonateName, metav1.GetOptions{})
+	if err == nil || errors.IsNotFound(err) {
+		_, err := kubeClient.RbacV1().Roles(namespace).Create(role)
+		if err != nil {
+			t.Fatalf("impersonate role creation failed namespace %q: %s", namespace, err)
+		}
+	} else {
+		t.Fatalf("Pre-check for impersonate failed namespace %q: %s", namespace, err)
+	}
+	roleBinding := &rbacv1.RoleBinding{
+		ObjectMeta: metav1.ObjectMeta{Name: impersonateName, Namespace: namespace},
+		Subjects: []rbacv1.Subject{
+			{
+				Kind:      "ServiceAccount",
+				Name:      sa,
+				Namespace: namespace,
+			},
+		},
+		RoleRef: rbacv1.RoleRef{
+			APIGroup: "rbac.authorization.k8s.io",
+			Kind:     "Role",
+			Name:     impersonateName,
+		},
+	}
+	_, err = kubeClient.RbacV1().RoleBindings(namespace).Get(impersonateName, metav1.GetOptions{})
+	if err == nil || errors.IsNotFound(err) {
+		_, err := kubeClient.RbacV1().RoleBindings(namespace).Create(roleBinding)
+		if err != nil {
+			t.Fatalf("View rolebinding creation failed namespace %q: %s", namespace, err)
+		}
+	} else {
+		t.Fatalf("Pre-check for view rolebinding failed namespace %q: %s", namespace, err)
+	}
+}
+
 func TestEventListenerCreate(t *testing.T) {
 	c, namespace := setup(t)
 	t.Parallel()
@@ -222,6 +274,8 @@ func TestEventListenerCreate(t *testing.T) {
 		t.Fatalf("Error creating RoleBinding: %s", err)
 	}
 
+	impersonateRBAC(t, sa.Name, namespace, c.KubeClient)
+
 	// EventListener
 	el, err := c.TriggersClient.TriggersV1alpha1().EventListeners(namespace).Create(
 		bldr.EventListener("my-eventlistener", namespace,
@@ -230,8 +284,10 @@ func TestEventListenerCreate(t *testing.T) {
 			),
 			bldr.EventListenerSpec(
 				bldr.EventListenerServiceAccount(sa.Name),
+				bldr.EventListenerReplicas(3),
 				bldr.EventListenerPodTemplate(
 					bldr.EventListenerPodTemplateSpec(
+						bldr.EventListenerPodTemplateNodeSelector(map[string]string{"beta.kubernetes.io/os": "linux"}),
 						bldr.EventListenerPodTemplateTolerations([]corev1.Toleration{
 							{
 								Key:      "key",
@@ -436,10 +492,7 @@ func TestEventListenerCreate(t *testing.T) {
 			return false, nil
 		}
 		for i, trigger := range el.Spec.Triggers {
-			trigger.ServiceAccount = &corev1.ObjectReference{
-				Namespace: namespace,
-				Name:      userWithoutPermissions,
-			}
+			trigger.ServiceAccountName = userWithoutPermissions
 			el.Spec.Triggers[i] = trigger
 		}
 		_, err = c.TriggersClient.TriggersV1alpha1().EventListeners(namespace).Update(el)
@@ -477,10 +530,7 @@ func TestEventListenerCreate(t *testing.T) {
 			return false, nil
 		}
 		for i, trigger := range el.Spec.Triggers {
-			trigger.ServiceAccount = &corev1.ObjectReference{
-				Namespace: namespace,
-				Name:      sa.Name,
-			}
+			trigger.ServiceAccountName = sa.Name
 			el.Spec.Triggers[i] = trigger
 		}
 		_, err = c.TriggersClient.TriggersV1alpha1().EventListeners(namespace).Update(el)
